@@ -4,8 +4,8 @@ Validates that snapshot data matches select_* method results before, during, and
 """
 
 import pytest
-from pdfdancer import ObjectType, PDFDancer
 
+from pdfdancer import ObjectType, PDFDancer
 from tests.e2e import _require_env_and_fixture
 
 
@@ -14,10 +14,10 @@ def test_page_snapshot_matches_select_paragraphs():
     base_url, token, pdf_path = _require_env_and_fixture("Showcase.pdf")
 
     with PDFDancer.open(pdf_path, token=token, base_url=base_url) as pdf:
-        page = pdf.page(0)
+        page = pdf.page(1)
 
         # Get data via snapshot
-        snapshot = pdf.get_page_snapshot(0)
+        snapshot = pdf.get_page_snapshot(1)
         snapshot_paragraphs = [
             e for e in snapshot.elements if e.type == ObjectType.PARAGRAPH
         ]
@@ -34,7 +34,7 @@ def test_page_snapshot_matches_select_paragraphs():
         selected_ids = {p.internal_id for p in selected_paragraphs}
 
         assert (
-                selected_ids == snapshot_ids
+            selected_ids == snapshot_ids
         ), "Snapshot and select_paragraphs() should return identical paragraph IDs"
 
 
@@ -43,9 +43,9 @@ def test_page_snapshot_matches_select_images():
     base_url, token, pdf_path = _require_env_and_fixture("Showcase.pdf")
 
     with PDFDancer.open(pdf_path, token=token, base_url=base_url) as pdf:
-        page = pdf.page(0)
+        page = pdf.page(1)
 
-        snapshot = pdf.get_page_snapshot(0)
+        snapshot = pdf.get_page_snapshot(1)
         snapshot_images = [e for e in snapshot.elements if e.type == ObjectType.IMAGE]
 
         selected_images = page.select_images()
@@ -59,7 +59,7 @@ def test_page_snapshot_matches_select_images():
             selected_ids = {img.internal_id for img in selected_images}
 
             assert (
-                    selected_ids == snapshot_ids
+                selected_ids == snapshot_ids
             ), "Snapshot and select_images() should return identical image IDs"
 
 
@@ -68,9 +68,9 @@ def test_page_snapshot_matches_select_forms():
     base_url, token, pdf_path = _require_env_and_fixture("Showcase.pdf")
 
     with PDFDancer.open(pdf_path, token=token, base_url=base_url) as pdf:
-        page = pdf.page(0)
+        page = pdf.page(1)
 
-        snapshot = pdf.get_page_snapshot(0)
+        snapshot = pdf.get_page_snapshot(1)
         snapshot_forms = [
             e for e in snapshot.elements if e.type == ObjectType.FORM_X_OBJECT
         ]
@@ -86,7 +86,7 @@ def test_page_snapshot_matches_select_forms():
             selected_ids = {form.internal_id for form in selected_forms}
 
             assert (
-                    selected_ids == snapshot_ids
+                selected_ids == snapshot_ids
             ), "Snapshot and select_forms() should return identical form IDs"
 
 
@@ -95,19 +95,19 @@ def test_page_snapshot_matches_select_form_fields():
     base_url, token, pdf_path = _require_env_and_fixture("Showcase.pdf")
 
     with PDFDancer.open(pdf_path, token=token, base_url=base_url) as pdf:
-        page = pdf.page(0)
+        page = pdf.page(1)
 
-        snapshot = pdf.get_page_snapshot(0)
+        snapshot = pdf.get_page_snapshot(1)
         snapshot_form_fields = [
             e
             for e in snapshot.elements
             if e.type
-               in (
-                   ObjectType.FORM_FIELD,
-                   ObjectType.TEXT_FIELD,
-                   ObjectType.CHECK_BOX,
-                   ObjectType.RADIO_BUTTON,
-               )
+            in (
+                ObjectType.FORM_FIELD,
+                ObjectType.TEXT_FIELD,
+                ObjectType.CHECK_BOX,
+                ObjectType.RADIO_BUTTON,
+            )
         ]
 
         selected_form_fields = page.select_form_fields()
@@ -121,7 +121,7 @@ def test_page_snapshot_matches_select_form_fields():
             selected_ids = {field.internal_id for field in selected_form_fields}
 
             assert (
-                    selected_ids == snapshot_ids
+                selected_ids == snapshot_ids
             ), "Snapshot and select_form_fields() should return identical form field IDs"
 
 
@@ -130,7 +130,7 @@ def test_page_snapshot_contains_all_element_types():
     base_url, token, pdf_path = _require_env_and_fixture("Showcase.pdf")
 
     with PDFDancer.open(pdf_path, token=token, base_url=base_url) as pdf:
-        snapshot = pdf.get_page_snapshot(0)
+        snapshot = pdf.get_page_snapshot(1)
 
         # Count elements by type
         paragraph_count = sum(
@@ -143,7 +143,7 @@ def test_page_snapshot_contains_all_element_types():
 
         # Verify we have at least some text elements
         assert (
-                paragraph_count > 0 or text_line_count > 0
+            paragraph_count > 0 or text_line_count > 0
         ), "Page should have at least some text elements"
 
         # Verify all elements have required fields
@@ -161,8 +161,8 @@ def test_document_snapshot_matches_all_pages():
         doc_snapshot = pdf.get_document_snapshot()
 
         # Verify each page matches individual page snapshot
-        for i in range(doc_snapshot.page_count):
-            doc_page_snap = doc_snapshot.pages[i]
+        for i in range(1, doc_snapshot.page_count + 1):
+            doc_page_snap = doc_snapshot.pages[i - 1]
             individual_page_snap = pdf.get_page_snapshot(i)
 
             assert len(individual_page_snap.elements) == len(
@@ -173,7 +173,7 @@ def test_document_snapshot_matches_all_pages():
             individual_page_ids = {e.internal_id for e in individual_page_snap.elements}
 
             assert (
-                    individual_page_ids == doc_page_ids
+                individual_page_ids == doc_page_ids
             ), f"Page {i} should have identical elements in document and individual snapshots"
 
 
@@ -183,10 +183,10 @@ def test_type_filter_matches_select_method():
 
     with PDFDancer.open(pdf_path, token=token, base_url=base_url) as pdf:
         # Get snapshot with PARAGRAPH filter
-        paragraph_snapshot = pdf.get_page_snapshot(0, "PARAGRAPH")
+        paragraph_snapshot = pdf.get_page_snapshot(1, "PARAGRAPH")
 
         # Get paragraphs via select method
-        selected_paragraphs = pdf.page(0).select_paragraphs()
+        selected_paragraphs = pdf.page(1).select_paragraphs()
 
         assert len(selected_paragraphs) == len(
             paragraph_snapshot.elements
@@ -201,7 +201,7 @@ def test_type_filter_matches_select_method():
         selected_ids = {p.internal_id for p in selected_paragraphs}
 
         assert (
-                selected_ids == snapshot_ids
+            selected_ids == snapshot_ids
         ), "Filtered snapshot and select_paragraphs() should return identical IDs"
 
 
@@ -211,7 +211,7 @@ def test_multiple_type_filters_combined():
 
     with PDFDancer.open(pdf_path, token=token, base_url=base_url) as pdf:
         # Get snapshot with multiple type filter
-        multi_snapshot = pdf.get_page_snapshot(0, "PARAGRAPH,TEXT_LINE")
+        multi_snapshot = pdf.get_page_snapshot(1, "PARAGRAPH,TEXT_LINE")
 
         # Verify only specified types are present
         assert all(
@@ -220,7 +220,7 @@ def test_multiple_type_filters_combined():
         ), "Multi-type filter should only contain specified types"
 
         # Count should be sum of those types from unfiltered snapshot
-        full_snapshot = pdf.get_page_snapshot(0)
+        full_snapshot = pdf.get_page_snapshot(1)
         expected_count = sum(
             1
             for e in full_snapshot.elements
@@ -239,7 +239,9 @@ def test_total_element_count_matches_expected():
     with PDFDancer.open(pdf_path, token=token, base_url=base_url) as pdf:
         # Showcase.pdf - Python API filters certain types (638)
         all_elements = pdf.select_elements()
-        assert 95 <= len(all_elements) <= 97, "Showcase.pdf should have 95 total elements"
+        assert (
+            95 <= len(all_elements) <= 97
+        ), "Showcase.pdf should have 95 total elements"
 
         doc_snapshot = pdf.get_document_snapshot()
         snapshot_total = sum(len(p.elements) for p in doc_snapshot.pages)
@@ -262,12 +264,12 @@ def test_snapshot_consistency_across_multiple_pages():
         assert doc_snapshot.page_count > 1, "Need multiple pages for this test"
 
         # Test that each page's snapshot is independent
-        for i in range(min(3, doc_snapshot.page_count)):
+        for i in range(1, min(4, doc_snapshot.page_count + 1)):
             page_snap = pdf.get_page_snapshot(i)
             assert page_snap is not None, f"Page {i} snapshot should not be None"
             assert (
-                    page_snap.page_ref.position.page_index == i
-            ), "Page snapshot should have correct page index"
+                page_snap.page_ref.position.page_number == i
+            ), "Page snapshot should have correct page number"
 
 
 @pytest.mark.skip(reason="TODO Not yet implemented")
@@ -280,7 +282,7 @@ def test_document_snapshot_contains_fonts():
 
         # Should have fonts
         assert (
-                doc_snapshot.fonts is not None
+            doc_snapshot.fonts is not None
         ), "Document snapshot should have fonts list"
         assert len(doc_snapshot.fonts) > 0, "Document should have at least one font"
 
@@ -289,5 +291,5 @@ def test_document_snapshot_contains_fonts():
             assert font.font_name is not None, "Font should have a name"
             assert font.font_type is not None, "Font should have a type"
             assert (
-                    font.similarity_score is not None
+                font.similarity_score is not None
             ), "Font should have similarity score"
